@@ -3,9 +3,9 @@ from matplotlib import path
 import numpy as np
 from .Constant import get_eps,get_sig_figures
 
-### Computation on 3D Lines and Polygons
+### Computation on the intersection of 3D Lines and 3D Polygons
 '''
-    All vertices need numpy.array(N,3)
+    All vertices follow the form of numpy.array(N,3)
 '''
 # Vectors
 
@@ -48,7 +48,7 @@ def Mask(v,bSelected):
     P = np.array(v)
     return P[bSelected]
 
-#判断矩阵，list，值等是否相同（在误差允许范围内），若相同，返回True
+# To check whether the two vectors are equal. If they are,  it returns True
 def Equal(a,b):
     return np.all(Round(a)==Round(b))
 
@@ -65,14 +65,15 @@ def ScalarZero(x):
 def Vertices(x):
     return Array(x)
 
-#计算直线与直线的交点，输入为两个直线上的一点和直线的斜率，，支持三维空间下的 计算，输出为
-##                                                              1.直线相交输出点Array（P)
-##                                                              2.直线平行输出None
-##                                                              3.直线重合输出‘Line’
-##                                                              4.直线相异输出None
-# 3D Lines
+# Intersection point of two 3D Lines with theri own points and slopes.
+# It returns, 
+# (1)Array（P), intersection point; 
+# (2)None, they are in parallel; 
+# (3)‘Line’, they are one; 
+# (4)None, they are different in 3D space. 
+
 def LineXLine(P1,L1,P2,L2):
-    ##向量单位化
+    # Normalize them
     L1  = UnitVector(np.array(L1))
     L2  = UnitVector(np.array(L2)) 
     C, D = Array(P1), Array(P2)
@@ -80,7 +81,7 @@ def LineXLine(P1,L1,P2,L2):
     e,f  = Array(L1), Array(L2)
     X = Cross(f,CD)
     Y = Cross(f,e)
-    ##判断向量是否为0
+    # To check if they are zeros
     if(np.linalg.norm(X) <= get_eps() and np.linalg.norm(Y)  <= get_eps()):
         return 'Line'
     else:
@@ -95,11 +96,12 @@ def LineXLine(P1,L1,P2,L2):
             else:
                 return M
 
-##判断点是否在直线上，支持三维计算，输入为点，直线上的一点，直线的斜率，输出为Ture和False
+# To check if the point P0 is on the 3D line(P,L), Ture/False
 def PointInLine(P0,P,L):
     V0 = Array(P0)
     V  = Array(P)
-    L1 = UnitVector( V0 - V)                ##UnitVector为之前定义的函数，用于向量单位化
+
+    L1 = UnitVector( V0 - V)
     Lx = UnitVector(Array(L))
     if Equal(L1, Lx) or Equal(L1, (-1)*Lx):
         return True
@@ -108,7 +110,7 @@ def PointInLine(P0,P,L):
 
 
 
-##判断点是否在线段上，支持三维计算，输入为点，线段的两个端点，输出为Ture或False
+# To check if  P is inside a segement(P1,P2), Ture/False
 def PointInSegment(P,P1,P2):
     pos = np.vstack((P1, P2))
     pos = np.array([np.min(pos[ :, :], axis=0),
@@ -118,26 +120,21 @@ def PointInSegment(P,P1,P2):
 
 # 3D Polygons
 '''
-   交点:
-   计算从 P0 出发的直线（L）与多边形（Polygon）相交
+   Core concern : intersection. 
+   That is, a line of slop (L) from a point (P0) is intercepted with a Polygon.
+   The process is decoupled into two steps :
+        (1) the line cross a plane;
+        (2) their intersection point falls in the polygon, including the border.
 
-        （1）直线与平面的交点；
-        （2）确定交点是否落在多边形区域内（包括边界上）。
-
-           P0      : the starting point ,
-                    P0 =np.array((x0,y0,z0))
-           L       : 
-                the slope of line
-                    L = np.array((dx,dy,dz))
-           Polygon : 
-                vertices of the polygon
-                    = np.array(
+           P0 =np.array((x0,y0,z0))
+           L  = np.array((dx,dy,dz))
+           Polygon = np.array(
                                 [x1 y1 z1],
                                 [x2 y2 z2],
                                 ...
                                 [xm ym zm])
 '''
-##判断线段和多边形的交点，输入线段的两个端点P1，P2和多边形，输出交点（暂未使用）
+# Intersection of a segement (P1,P2) with a polygon
 def SegmentXPolygon(P1,P2,polygon):
     L  = UnitVector(np.array(P2) - np.array(P1))
     P0 = P1
@@ -152,31 +149,33 @@ def SegmentXPolygon(P1,P2,polygon):
        else :
            return None
 
-##计算直线和线段的交点，只支持二维下的计算，输入直线上的一点和直线的斜率，线段端点的x，y值，输出：
-##                                                              1.相交于一点输出点Array（P)
-##                                                              2.无交点输出None
-##                                                              3.直线与线段重合输出‘Line’
+# Intersection of a segement (x1,y1),(x2,y2) with a 2D line.
+# It returns :
+# (1) Array（P), intersecting point;
+# (2) None, No intersection;
+# (3) ‘Line’, the segment if part of the line
 def LineXSegment2D(P0,L,x1,y1,x2,y2):
     P1,L1,P2=(x1,y1),(x1-x2,y1-y2),(x2,y2)
     L1  = UnitVector(np.array(L1))
     if np.linalg.norm(L1) <= get_eps():
         return None
     else:
-        P=LineXLine(P0,L,P1,L1)             ##点坐标的计算是用直线相交的函数进行计算
+        P=LineXLine(P0,L,P1,L1)  
         if P is None:
             return None
         elif P == 'Line':
             return P
         else:
-            if PointInSegment(P,P1,P2):     ##所以需要判断点是否在线段上
+            if PointInSegment(P,P1,P2): 
                 return P
             else:
                 return None
 
-##计算直线和多边形的交点，（多边形不能是凹多边形）只支持二维下的计算，输入直线上的一点和直线的斜率，多边形的矩阵，输出为2个值：
-##                                                              1.相交于一点输出点Array（P1)，None
-##                                                              2.无交点输出None，None
-##                                                              3.直线与多边形有两个交点输出‘Array（P1)，Array（P2)
+# Intersection of line with polygon in 2D space.
+# It returns a pair of values as follow,
+#(1) P1，None : one intersection point
+#(2) None，None : no intersection
+#(3) P1，P2 : two intersection points
 def LineXPolygon2D(P0,L,Polygon):
     L=UnitVector(L) 
     n = len(Polygon)
@@ -186,10 +185,10 @@ def LineXPolygon2D(P0,L,Polygon):
     for i in range(n):
         x1,y1 = Polygon[i]
         x2,y2 = Polygon[(i+1)%n]
-        P = LineXSegment2D(P0,L,x1,y1,x2,y2)  ##通过计算线与多边形每一条边的交点计算它与多边形的交点
+        P = LineXSegment2D(P0,L,x1,y1,x2,y2)  # to check its intersection with each edge of the polygon
         if P is None :
             pass
-        elif P == 'Line':                       ##直线与线段重合
+        elif P == 'Line':                       # the edge is part of line
             P1,P2=(x1,y1),(x2,y2)
             return P1,P2
         else:
@@ -207,18 +206,19 @@ def LineXPolygon2D(P0,L,Polygon):
     else:
         return P1,None
 
-####计算直线和多边形的交点，（多边形不能是凹多边形）三维下的计算，输入直线上的一点和直线的斜率，多边形的矩阵，输出为1个值：
-##                                                              1.相交于一点输出点Array（P1)
-##                                                              2.无交点输出None，None
-##                                                              3.直线与多边形有两个交点输出‘Line’，同时会输出一段文字提示
+# In 3D space, intersection of a line with a polygon
+# It return a pair of follwoing values ,
+# (1) P1, the intersection point;
+# (2) None, no intersection;
+# (3) 'Line', plus a warning message on console: there are two points of intersection
 def LineXPolygon(P0,L,Polygon):
     n = PolygonNormal(Polygon)          # [dx,dy,dz] 
     R0 = np.array(Polygon[0,:])          # [x,y,z]
-    Point = LineXPlane(P0,L,R0,n)          #用直线和面的交点函数求交点
+    Point = LineXPlane(P0,L,R0,n)          # intersection of line with plane
 
     if Point is None:
         return None
-    if Point == 'Line':                #如果直线在平面内，就线用转换矩阵转到二维，再用二维下的公式
+    if Point == 'Line':                # If the line lies in the plane, it goes into 2D space
         PL=P0+L
         P03D,Polygon3D,U,R0=D3ToD2(P0,Polygon)                      ##从三维矩阵变成二维
         PL3D,Polygon3D,U,R0=D3ToD2(PL,Polygon)
@@ -235,17 +235,19 @@ def LineXPolygon(P0,L,Polygon):
         else:
             P1=D2toD3Point(P1,U,R0)
             P2=D2toD3Point(P2,U,R0)
-            print('相交的图形是一个线段，端点分别为',np.around(P1, decimals=3, out=None),np.around(P2, decimals=3, out=None))
-            return 'Line'
+            print('intesection leaves a segment of ',np.around(P1, decimals=3, out=None),np.around(P2, decimals=3, out=None))
+            return 'Line', P1, P2
     if PointInPolygon(Point,Polygon) :
         return Point
     else :
         return None
 
-#####计算直线和平面的交点，（多边形不能是凹多边形）三维下的计算，输入直线上的一点和直线的斜率，平面上的一点和平面的法向量，输出：
-##                                                              1.相交于一点输出点Array（P1)
-##                                                              2.无交点输出None
-##                                                              3.直线与在平面上输出‘Line’
+# Intersection of a 3D line with a 3D plane
+# It returns
+# (1) P1
+# (2) None
+# (3)‘Line’, the line is one the plane
+
 def LineXPlane(P0,L,R0,n):
     L = UnitVector(L) 
     n_dot_L = Dot(n,L)
@@ -262,26 +264,28 @@ def LineXPlane(P0,L,R0,n):
     return P
 
 
-##三维坐标转为二维坐标，输入要转换的点和多边形，返回的点为（0，0，0）是三维点，vertices3D是三维坐标，U是变换矩阵，R0是基准点（一般不直接使用）
+# transformation from 3D to 2D
 def D3ToD2(Point,Polygon):
     U  = GetU(Polygon)
     R  = Array(Polygon)
     R0 = Array(Polygon[0,:])
     P  = Array(Point)
-    r = U@(R - R0).T  #@表示矩阵乘法
+    r = U@(R - R0).T  # @ is for vector times matrix
     p = U@(P - R0).T
     xy=p.T
     vertices3D = r.T
     vertices2D = r.T[:,0:2]
     return xy,vertices3D,U,R0
-##二维坐标转为三维坐标，输入要转换的多边形，U是变换矩阵，R0是基准点，返回vertices3D是三维坐标，（一般不直接使用）
+
+# transformation from 2D to 3D : polygon
 def D2toD3Polygon(Polygon,U,R0):
     r=Polygon.T
     U=np.mat(U)
     U=U.I
     R=(U@r).T+R0
     return R
-##二维坐标转为三维坐标，输入要转换的点，U是变换矩阵，R0是基准点，返回vertices3D是三维坐标，（一般不直接使用）
+
+# transformation from 2D to 3D : Point
 def D2toD3Point(Point,U,R0):
     Point3D=np.array([[Point[0]],[Point[1]],[0]])
     p=Point3D
@@ -290,23 +294,24 @@ def D2toD3Point(Point,U,R0):
     R=(U@p).T+R0
     return R
 
-##判断点是否在多边形内部，输入点和多边形，仅适用于单个点的情况。返回True或False
+# To check if a single point lies in a polygon, True/False
 def PointInPolygon(Point,Polygon):
     p,vertices3D,U,R0=D3ToD2(Point,Polygon)
     z=p[2]
     vertices2D = vertices3D[:,0:2]
-    if ScalarZero(z) :                  ##若变换之后z坐标不为0说明点没有落在平面上
+    if ScalarZero(z) :                  # In local 2D coordiates, if z = 0 , the point is in the plane
         xy = p[0:2]   # first two columns 
         return PointInPolygon2D(xy[0], xy[1], vertices2D)
     else :
         return False
 
-##判断点是否在多边形内部，输入点和多边形，适用于单个点或多个点的情况。返回True或False
+# To check if many points lie in a polygon, True/False
 def PointsInPolygon(Points,Polygon):
     Points = np.array(Points)
-    ##多维数组转成1
+
+    # set it unitary
     j=0
-    if Points.ndim ==1:
+    if Points.ndim == 1:
         return PointInPolygon(Points,Polygon)
     elif Points.ndim ==3:
         j=1
@@ -314,26 +319,29 @@ def PointsInPolygon(Points,Polygon):
         a=dimen[0]
         b=dimen[1]
         Points = Points.reshape(int(a*b),3)
+
     U  = GetU(Polygon)
     R  = Array(Polygon)
     R0 = Array(Polygon[0,:])
     Ps = Array(Points)
-    r = U@(R - R0).T
-    p = U@(Ps - R0).T
-    n = len(p[0])                   ##判断点的z坐标是否为0，不为0说明不在面上
+    r  = U@(R - R0).T
+    p  = U@(Ps - R0).T
+    n  = len(p[0])                   # to check is z == 0
     ret = np.array(list(False for i in range(n)))
+
     for i in range(n):
         if ScalarZero(p[2,i]):
             ret[i] = True
 
     xy = (p[0:2]).T   # first two columns 
     vertices2D = r.T[:,0:2]
-    if j==1:
+    if j == 1:
         ret = ret.reshape(a,b)
-        xy=xy.reshape(a,b,2)
-    ret=ret*PointsInPolygon2D(xy, vertices2D)
+        xy = xy.reshape(a,b,2)
+    ret = ret*PointsInPolygon2D(xy, vertices2D)
     return ret
-##多点在多边形的关系判断方法2
+
+# multiple points in a polygon : variant method 0
 def PointsInPolygon0(Points,Polygon):
     Points = np.array(Points)
     ret=[]
@@ -352,7 +360,7 @@ def PointsInPolygon0(Points,Polygon):
     else:
         return None
 
-##多点在多边形的关系判断方法3
+# multiple points in a polygon : variant method 1
 def PointsInPolygon1(Points,Polygon):
     Points = np.array(Points)
     if Points.ndim ==2:
@@ -374,7 +382,7 @@ def PointsInPolygon1(Points,Polygon):
         return None
 
 
-##判断点是否在多边形内部，输入点和多边形，适用于单个点或多个点的情况。仅适用于二维。返回True或False
+# multiple points in a polygon : 2D space only
 def PointsInPolygon2D(Points,Polygon,Method='Custom'):
     from functools import reduce
     from operator import mul
@@ -383,7 +391,7 @@ def PointsInPolygon2D(Points,Polygon,Method='Custom'):
     if type(Points) is not np.array:
         Vertices = Array(Points)
 
-    # one Point
+    # Single Point
     # 1) input as np.array([7,8]), shape =(2,)
     if len(Vertices.shape) == 1 :
         x0 = Vertices[0]
@@ -399,7 +407,7 @@ def PointsInPolygon2D(Points,Polygon,Method='Custom'):
         ret = PointInPolygon2D(x0,y0,Polygon)
         return ret
 
-    # Many Points
+    # Multiple Points
     shape = np.shape(Vertices)    #  0,...,n-1
     matrix_shape = shape[0:-1]  #  0,...,n-2, excluding shape[-1]
     n = reduce(mul, matrix_shape, 1)   #  how many points
@@ -413,7 +421,8 @@ def PointsInPolygon2D(Points,Polygon,Method='Custom'):
         ret = _PointsInPolygon2D_Matplotlib(Points_array, Polygon)
 
     return ret.reshape(matrix_shape)
-##上述函数的分支之一
+
+# help functions 
 def _PointsInPolygon2D_Custom(Points,Polygon):
 
     n = len(Points)
@@ -422,7 +431,7 @@ def _PointsInPolygon2D_Custom(Points,Polygon):
         x0,y0  = Points[i]
         ret[i] = PointInPolygon2D(x0,y0,Polygon)   
     return ret
-##上述函数的分支之二
+
 def _PointsInPolygon2D_Matplotlib(Points,Polygon):
     row = len(Polygon)   # row = N, Polygon = N x 2   
     
@@ -459,7 +468,8 @@ def _PointsInPolygon2D_Matplotlib(Points,Polygon):
                                      
     # inside + on Edge
     return ret
-##判断点是否在多边形内部，输入点和多边形，仅适用于单个点的情况。仅适用于二维。返回True或False
+
+# a 2D point inside a 2D polygon, it return True/False
 def PointInPolygon2D(x0,y0,Polygon):
     """
        return value :
@@ -488,18 +498,17 @@ def PointInPolygon2D(x0,y0,Polygon):
     else:
         return False
 
-#从点处向x轴正方向做直线，判断点的位置。服务于用于判断点是否在二维多边形内的函数，意义不大，一般不直接使用 输入为点的横纵坐标，线段两个端点的横纵坐标。
-    #规定射线经过的点属于射线上的一侧
     """
-    从点处向x轴正方向做射线，判断点的位置
+    Starting from a point P0, a ray goes to the right.
         INTERSECTION ?
-            ret=O  NO  ( no crossover point )  直线和所给线段没有交点
-            ret=1  Have  ( have a crossover point,  )直线和所给线段有交点
-            ret=2  YES ( ON EDGE )  点刚好在线段上
+            ret=O  NO  ( no any intersection with edges )
+            ret=1  YES ( There is one intersection point, P0 is internal.) 
+            ret=2  YES ( P0 is ON EDGE ) 
     """
     # ymin < y0 < ymax 
 def PointInSegment2Dold(x0,y0,x1,y1,x2,y2):
-    if ScalarEqual(max(y1,y2),y0) or ScalarEqual(min(y1,y2),y0) or ((max(y1,y2)>y0) & ( y0>min(y1,y2))):   ##    if (max(y1,y2)>=y0) & ( y0>=min(y1,y2)) :    #规定射线经过的点属于射线上的一侧
+    if ScalarEqual(max(y1,y2),y0) or ScalarEqual(min(y1,y2),y0) or ((max(y1,y2)>y0) & ( y0>min(y1,y2))):   
+    #    if (max(y1,y2)>=y0) & ( y0>=min(y1,y2)) in the condition that all intersection occurs by the right
         if not ScalarEqual(y1 , y2) :   # y1 != y2 :
             if not ScalarEqual(x1, x2) : # x1 != x2 :
                 x=x1+(y0-y1)*(x2-x1)/(y2-y1)   # predicted point
@@ -536,7 +545,8 @@ def PointInSegment2Dold(x0,y0,x1,y1,x2,y2):
         return 0
 
 def PointInSegment2D(x0,y0,x1,y1,x2,y2):
-    if ScalarEqual(max(y1,y2),y0) or ((max(y1,y2)>y0) & ( y0>min(y1,y2))):   ##    if (max(y1,y2)>=y0) & ( y0>=min(y1,y2)) :    #规定射线经过的点属于射线上的一侧
+    if ScalarEqual(max(y1,y2),y0) or ((max(y1,y2)>y0) & ( y0>min(y1,y2))):   
+    #  if (max(y1,y2)>=y0) & ( y0>=min(y1,y2)) in the condition that all intersection occurs by the right
         if not ScalarEqual(y1 , y2) :   # y1 != y2 :
             x=x1+(y0-y1)*(x2-x1)/(y2-y1)   # predicted point
             if  ScalarEqual(x0, x) :  # x0 == x :
@@ -563,7 +573,7 @@ def PointInSegment2D(x0,y0,x1,y1,x2,y2):
     else:
         return 0
 
-##得到一个垂直于多边形的向量，输入为多边形Polygon 输出为垂直于多边形的单位向量
+# To obtain a normal unitary vector of a polygon
 def PolygonNormal(v):
     """
        get a vector normal to the polygon 
@@ -579,7 +589,7 @@ def PolygonNormal(v):
     
     return UnitVector(C)
 
-##用于得到多边形从三维到二维对应的转换矩阵
+# To obtain a transformation of a polygon from its 3D to 2D
 def GetU(polygon):
     """
         Get transform matrix of a polyogn
@@ -614,7 +624,6 @@ def GetU(polygon):
 
 
 # element-wise view factor
-##用于角系数的计算（暂未应用）
 def fij(P1, P2, n1, n2, A2 ):
     '''
     P1,P2 : centers of two elements, np.array([x,y,z])
@@ -634,272 +643,6 @@ def fij(P1, P2, n1, n2, A2 ):
     return f12
 
 
-"""
-    Rapid Creation of 3D Polygons
-      - Shape Functions
-         (1) Input a 2D Polygon in yz Plane 
-         (2) Move it to a 3D position
-"""
-def add_col(n, dtype=int):
-    """
-    It adds a column of length n
-    return a column of array.
-    """
-    return np.reshape(np.arange(n, dtype = dtype), (n, 1))
-
-from math import *
-# 1) To create a dictionary list that holds all arguments 
-#      for shapes just inputed.
-__shapeInputDicts = []
-
-def  shapeInputDict(each_shape_input):
-    __shapeInputDicts.append(each_shape_input)
-    return each_shape_input
-
-@shapeInputDict
-def dict_rectangle(*args):
-    return {"shape":"rectangle","W":args[0],"H":args[1]}
-
-@shapeInputDict
-def dict_triangle(*args):
-    return {"shape":"triangle","W" : args[0], "H" : args[1], "A" : args[2]}
-
-@shapeInputDict
-def dict_rectangleWithHole(*args):
-    return {
-            "shape":"rectangleWithHole",
-            "W" : args[0],
-            "H" : args[1], 
-            "A" : args[2],
-            "B" : args[3],
-            "C" : args[4],
-            "D" : args[5]}
-
-@shapeInputDict
-def dict_fourSided(*args):
-    return {
-            "shape":"fourSided","W" : args[0],
-            "H" : args[1], 
-            "A" : args[2],
-            "B" : args[3],
-            "C" : args[4]}
-
-@shapeInputDict
-def dict_fiveSided(*args):
-    return {
-            "shape":"fiveSided","W" : args[0],"W" : args[0],
-            "H" : args[1], 
-            "A" : args[2],
-            "B" : args[3],
-            "C" : args[4],
-            "D" : args[5]}
-
-@shapeInputDict
-def dict_regularPolygon(*args):
-    return {
-            "n": args[0], 
-            "R": args[1],
-            "Center": args[2]
-            }
-
-@shapeInputDict
-def dict_polygon(*args):
-    # return np.array(list(map(lambda x:x,args)))
-    return  np.array(list(map(lambda x:x,args[0])))
-
-
-#2) to create vertices (0,y,z) for each shape
-__shapeFunctions = []
-
-def  shapeFunction(each_shape_func):
-    __shapeFunctions.append(each_shape_func)
-    return each_shape_func
-
-@shapeFunction
-def rectangle(*args):
-    dict_rectangle(*args)
-    W = args[0]
-    H = args[1]
-    return np.array([(0,0,0),(0,W,0),(0,W,H),(0,0,H)])
-
-@shapeFunction
-def triangle(*args):
-    dict_triangle(*args)
-    W = args[0]
-    H = args[1] 
-    A = args[2]
-    return np.array([(0,0,0),(0,W,0),(0,A,H)])
-
-@shapeFunction
-def rectangleWithHole(*args):
-    dict_rectangleWithHole(*args)
-
-    W = args[0]
-    H = args[1] 
-    A = args[2]
-    B = args[3]
-    C = args[4]
-    D = args[5]
-
-    if A>0 and B>0 and (A+C)<W and (B+D)<H :
-        ret = np.array([(0,0,0),(0,W,0),(0,W,H),(0,A,H),(0,A,D+B),(0,A+C,B+D),(0,A+C,B),(0,A,B),(0,A,H),(0,0,H)])
-
-    elif A == 0.0 :
-        if B == 0.0 and C < W and D < H :
-            ret = np.array([(0,C,0),(0,W,0),(0,W,H),(0,0,H),(0,0,D),(0,C,D)])
-
-        if B != 0.0 and C < W and (B+D) < H :
-            ret = rectangle(W=W-C,H=H) + (0,C,0)
-
-        if B != 0.0 and C < W and (B+D) >= H :
-            ret = np.array([(0,0,0),(0,W,0),(0,W,H),(0,C,H),(0,C,B),(0,0,B)])
-
-
-    elif A != 0.0 :
-        if B == 0.0 and (A+C) < W and D < H :
-            ret = np.array([(0,0,0),(0,A,0),(0,A,D),(0,A+C,D),(0,A+C,0),(0,W,0),(0,W,H),(0,0,H)])
-                
-        if B != 0.0 and (A+C) < W and (B+D) >= H :
-            ret = np.array([(0,0,0),(0,W,0),(0,W,H),(0,A+C,H),(0,A+C,B),(0,A,B),(0,A,H),(0,0,H)])
-
-        if B == 0.0 and (A+C) >= W and D < H :
-            ret = np.array([(0,0,0),(0,A,0),(0,A,D),(0,A+C,D),(0,W,H),(0,0,H)])
-
-        if B != 0.0 and (A+C) >= W and (B+D) < H :
-            ret = np.array([(0,0,0),(0,W,0),(0,W,B),(0,A,B),(0,A,B+D),(0,W,B+D),(0,W,H),(0,0,H)])
-
-        if B != 0.0 and (A+C) >= W and (B+D) >= H :
-            ret = np.array([(0,0,0),(0,W,0),(0,W,B),(0,A,B),(0,A,H),(0,0,H)])
-
-    else :
-        raise ValueError(f"Incorrect inputs : W={W}, H={H}, A={A}, B={B}, C={C}, D={D}")
-
-    return ret 
-
-@shapeFunction
-def fourSided(*args):
-    dict_fourSided(*args)
-    W = args[0]
-    H = args[1] 
-    A = args[2]
-    B = args[3]
-    C = args[4]
-    return np.array([(0,0,0),(0,W,0),(0,A+C,H),(0,A,B)])
-
-@shapeFunction
-def fiveSided(*args):
-    dict_fiveSided(*args)
-    W = args[0]
-    H = args[1] 
-    A = args[2]
-    B = args[3]
-    C = args[4]
-    D = args[5]
-    return np.array([(0,0,0),(0,W,0),(0,W+C,D),(0,A+B,H),(0,A,H)])
-
-@shapeFunction
-def regularPolygon(*args):
-    if len(args) < 3 :
-        raise ValueError("arguments are : n , R, Center ")
-        return
-    dict_regularPolygon(*args)
-
-    n     = args[0]
-    R     = args[1] 
-    Center= args[2]
-
-    if n < 3 :
-        return
-
-    theta = pi/n
-    s = R * sin(theta)
-    a = R * cos(theta)
-
-    theta = 2*pi/n
-    vertices = []
-    for i in range(n):
-        angle = i * theta
-        x = 0.0
-        y = R * cos(angle)
-        z = R * sin(angle)
-        vertices.append((x,y,z))
-
-    return np.array(vertices)  #,s,a
-
-@shapeFunction
-def polygon(*args):
-    value = args[0]
-    if isinstance(value,list):
-        vertices = np.array(value)
-    elif isinstance(value,np.ndarray) :
-        vertices = value
-    else :
-        raise ValueError('CoreUtils.polygon needs a list/np.array for vertices')
-
-    dict_polygon(*args)
-
-    if vertices.shape[1] == 2:
-    # from Utilities import add_col
-        vertices = np.hstack((add_col(vertices.shape[0])*0, vertices))
-
-    # return np.array(list(map(lambda x:x,args)))
-    return np.array(vertices)
-    
-
-# create a namelist of these function
-__shapeNames = [func.__name__ for func in __shapeFunctions ]
-
-def createShape(shapeName,*args):
-    name = [x.lower() for x in __shapeNames]
-    i = name.index(shapeName.lower())
-    __shapeInputDicts[i](*args)
-    return __shapeFunctions[i](*args)
-
-def shapes():
-    for each in __shapeNames:
-        print(each)
-
-def getShapeInputDict(shapeName,*args):
-    name = [x.lower() for x in __shapeNames]
-    i = name.index(shapeName.lower())
-    return __shapeInputDicts[i](*args)
-
-# For a 2D shape created at the initial position,
-# one can move it to a desired position by a matrix below
-def tranMatrix(alpha, beta):
-    al = radians(alpha)
-    be = radians(beta)
-    X = [cos(be)*cos(al), -sin(al), -sin(be)*cos(al)]
-    Y = [cos(be)*sin(al),  cos(al), -sin(be)*sin(al)]
-    Z = [sin(be), 0, cos(be)]
-    return np.vstack([X,Y,Z])
-
-# move from the intial position to a desired position
-def move(shape = rectangle(1.0,1.0), reference = (0.0,0.0,0.0), to = (0.0,0.0,0.0), by = (30.0,0.0)):
-    (alpha, beta) = by
-    # Comment them out for fast run
-    # if (type(shape) is list) or type(shape) is tuple:
-    #     vertices = np.array(shape)
-    # elif type(shape) is np.ndarray :
-    #     vertices = shape
-    # else :
-    #     raise ValueError('move() needs a list/np.array for a polygon')
-
-    vertices = shape
-    if vertices.shape[1] == 2:
-        vertices = np.hstack((add_col(vertices.shape[0])*0, vertices))
-    
-    facet = vertices.transpose() 
-
-    R1 = np.array(reference).reshape(-1,1) 
-    R2 = np.array(to).reshape(-1,1)
-    dR = R2 - R1
-
-    U = tranMatrix(alpha,beta)
-    facet_new = U.dot(facet) + dR
-
-    return facet_new.transpose()
-
 #
 #  Demo how to use them
 #
